/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'pass_mtx_method_channel.dart';

abstract class PassMtxPlatform extends PlatformInterface {
  /// Constructs a PassMtxPlatform.
  PassMtxPlatform() : super(token: _token);

  static final Object _token = Object();

  static PassMtxPlatform _instance = MethodChannelPassMtx();

  /// The default instance of [PassMtxPlatform] to use.
  ///
  /// Defaults to [MethodChannelPassMtx].
  static PassMtxPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [PassMtxPlatform] when
  /// they register themselves.
  static set instance(PassMtxPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future<String?> getPassPing() {
    throw UnimplementedError('getPassPing() has not been implemented.');
  }

  Future<String?> getPassVersion() {
    throw UnimplementedError('getPassVersion() has not been implemented.');
  }

  Future<String?> init(
      String appId, String clientId, String privatePem, String publicPem) {
    throw UnimplementedError('init() has not been implemented.');
  }

  Future<String?> initProd(
      String appId, String clientId, String privatePem, String publicPem) {
    throw UnimplementedError('initProd() has not been implemented.');
  }

  Future<String?> getCard(String userId) {
    throw UnimplementedError('getCard() has not been implemented.');
  }

  Future<String?> saveCard(String userId, String szPan, String cvv,
      String expDate, String cardHolderName) {
    throw UnimplementedError('saveCard() has not been implemented.');
  }

  Future<String?> purchase(
      String userId,
      String orderId,
      String paymentToken,
      String expDate,
      String paymentAmount,
      String dbRefNo,
      String description) {
    throw UnimplementedError('purchase() has not been implemented.');
  }

  Future<String?> enquery(String orderId) {
    throw UnimplementedError('saveCard() has not been implemented.');
  }

  Future<String?> deleteCard(String userId) {
    throw UnimplementedError('deleteCard() has not been implemented.');
  }

  Future<String?> verifyCard(
      String userId, String verificationMethod, String verificationValue) {
    throw UnimplementedError('verifyCard() has not been implemented.');
  }
}
